# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core/protos/model.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


try:
  from tensorflow.core.protobuf import meta_graph_pb2 as tensorflow_dot_core_dot_protobuf_dot_meta__graph__pb2
except ImportError:
  from tensorflow_protos.core.protobuf import meta_graph_pb2 as tensorflow_dot_core_dot_protobuf_dot_meta__graph__pb2

from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='core/protos/model.proto',
  package='modelhub',
  syntax='proto3',
  serialized_pb=_b('\n\x17\x63ore/protos/model.proto\x12\x08modelhub\x1a)tensorflow/core/protobuf/meta_graph.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9e\x02\n\x0eSavedModelInfo\x12\x0c\n\x04tags\x18\x01 \x03(\t\x12\x1a\n\x12tensorflow_version\x18\x02 \x01(\t\x12\x1e\n\x16tensorflow_git_version\x18\x03 \x01(\t\x12\x41\n\rsignature_def\x18\x04 \x03(\x0b\x32*.modelhub.SavedModelInfo.SignatureDefEntry\x12\x30\n\x0e\x61sset_file_def\x18\x05 \x03(\x0b\x32\x18.tensorflow.AssetFileDef\x1aM\n\x11SignatureDefEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.tensorflow.SignatureDef:\x02\x38\x01\"<\n\x07\x46ileDef\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x11\n\tfile_size\x18\x02 \x01(\x03\x12\x0b\n\x03md5\x18\x03 \x01(\t\"\x86\x03\n\x0cModelVersion\x12\x0b\n\x03seq\x18\x01 \x01(\x05\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\x12\x17\n\x0fsubmit_username\x18\x03 \x01(\t\x12\x14\n\x0csubmit_email\x18\x04 \x01(\t\x12\x33\n\x0fsubmit_datetime\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0brequire_gpu\x18\x06 \x01(\x08\x12\x13\n\x0b\x61pi_py_name\x18\x07 \x01(\t\x12\x11\n\tfile_name\x18\x08 \x01(\t\x12\x17\n\x0f\x63ompressed_size\x18\t \x01(\x03\x12\x16\n\x0e\x63ompressed_md5\x18\n \x01(\t\x12\x16\n\x0eis_saved_model\x18\x0b \x01(\x08\x12\x32\n\x10saved_model_info\x18\x0c \x03(\x0b\x32\x18.modelhub.SavedModelInfo\x12\x18\n\x10modelhub_version\x18\r \x01(\t\x12 \n\x05\x66iles\x18\x0e \x03(\x0b\x32\x11.modelhub.FileDef\"\xec\x01\n\x05Model\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nowner_name\x18\x03 \x01(\t\x12\x13\n\x0bowner_email\x18\x04 \x01(\t\x12(\n\x08versions\x18\x05 \x03(\x0b\x32\x16.modelhub.ModelVersion\x12\x33\n\x0f\x63reate_datetime\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14last_update_datetime\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestampb\x06proto3')
  ,
  dependencies=[tensorflow_dot_core_dot_protobuf_dot_meta__graph__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_SAVEDMODELINFO_SIGNATUREDEFENTRY = _descriptor.Descriptor(
  name='SignatureDefEntry',
  full_name='modelhub.SavedModelInfo.SignatureDefEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='modelhub.SavedModelInfo.SignatureDefEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='modelhub.SavedModelInfo.SignatureDefEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=323,
  serialized_end=400,
)

_SAVEDMODELINFO = _descriptor.Descriptor(
  name='SavedModelInfo',
  full_name='modelhub.SavedModelInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags', full_name='modelhub.SavedModelInfo.tags', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tensorflow_version', full_name='modelhub.SavedModelInfo.tensorflow_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tensorflow_git_version', full_name='modelhub.SavedModelInfo.tensorflow_git_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature_def', full_name='modelhub.SavedModelInfo.signature_def', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset_file_def', full_name='modelhub.SavedModelInfo.asset_file_def', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SAVEDMODELINFO_SIGNATUREDEFENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=400,
)


_FILEDEF = _descriptor.Descriptor(
  name='FileDef',
  full_name='modelhub.FileDef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_name', full_name='modelhub.FileDef.file_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='modelhub.FileDef.file_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='md5', full_name='modelhub.FileDef.md5', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=402,
  serialized_end=462,
)


_MODELVERSION = _descriptor.Descriptor(
  name='ModelVersion',
  full_name='modelhub.ModelVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='modelhub.ModelVersion.seq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='modelhub.ModelVersion.comment', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='submit_username', full_name='modelhub.ModelVersion.submit_username', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='submit_email', full_name='modelhub.ModelVersion.submit_email', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='submit_datetime', full_name='modelhub.ModelVersion.submit_datetime', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='require_gpu', full_name='modelhub.ModelVersion.require_gpu', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='api_py_name', full_name='modelhub.ModelVersion.api_py_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='modelhub.ModelVersion.file_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compressed_size', full_name='modelhub.ModelVersion.compressed_size', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compressed_md5', full_name='modelhub.ModelVersion.compressed_md5', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_saved_model', full_name='modelhub.ModelVersion.is_saved_model', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='saved_model_info', full_name='modelhub.ModelVersion.saved_model_info', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modelhub_version', full_name='modelhub.ModelVersion.modelhub_version', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='files', full_name='modelhub.ModelVersion.files', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=465,
  serialized_end=855,
)


_MODEL = _descriptor.Descriptor(
  name='Model',
  full_name='modelhub.Model',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='modelhub.Model.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='modelhub.Model.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_name', full_name='modelhub.Model.owner_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_email', full_name='modelhub.Model.owner_email', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='versions', full_name='modelhub.Model.versions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_datetime', full_name='modelhub.Model.create_datetime', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_update_datetime', full_name='modelhub.Model.last_update_datetime', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=858,
  serialized_end=1094,
)

_SAVEDMODELINFO_SIGNATUREDEFENTRY.fields_by_name['value'].message_type = tensorflow_dot_core_dot_protobuf_dot_meta__graph__pb2._SIGNATUREDEF
_SAVEDMODELINFO_SIGNATUREDEFENTRY.containing_type = _SAVEDMODELINFO
_SAVEDMODELINFO.fields_by_name['signature_def'].message_type = _SAVEDMODELINFO_SIGNATUREDEFENTRY
_SAVEDMODELINFO.fields_by_name['asset_file_def'].message_type = tensorflow_dot_core_dot_protobuf_dot_meta__graph__pb2._ASSETFILEDEF
_MODELVERSION.fields_by_name['submit_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MODELVERSION.fields_by_name['saved_model_info'].message_type = _SAVEDMODELINFO
_MODELVERSION.fields_by_name['files'].message_type = _FILEDEF
_MODEL.fields_by_name['versions'].message_type = _MODELVERSION
_MODEL.fields_by_name['create_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MODEL.fields_by_name['last_update_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['SavedModelInfo'] = _SAVEDMODELINFO
DESCRIPTOR.message_types_by_name['FileDef'] = _FILEDEF
DESCRIPTOR.message_types_by_name['ModelVersion'] = _MODELVERSION
DESCRIPTOR.message_types_by_name['Model'] = _MODEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SavedModelInfo = _reflection.GeneratedProtocolMessageType('SavedModelInfo', (_message.Message,), dict(

  SignatureDefEntry = _reflection.GeneratedProtocolMessageType('SignatureDefEntry', (_message.Message,), dict(
    DESCRIPTOR = _SAVEDMODELINFO_SIGNATUREDEFENTRY,
    __module__ = 'core.protos.model_pb2'
    # @@protoc_insertion_point(class_scope:modelhub.SavedModelInfo.SignatureDefEntry)
    ))
  ,
  DESCRIPTOR = _SAVEDMODELINFO,
  __module__ = 'core.protos.model_pb2'
  # @@protoc_insertion_point(class_scope:modelhub.SavedModelInfo)
  ))
_sym_db.RegisterMessage(SavedModelInfo)
_sym_db.RegisterMessage(SavedModelInfo.SignatureDefEntry)

FileDef = _reflection.GeneratedProtocolMessageType('FileDef', (_message.Message,), dict(
  DESCRIPTOR = _FILEDEF,
  __module__ = 'core.protos.model_pb2'
  # @@protoc_insertion_point(class_scope:modelhub.FileDef)
  ))
_sym_db.RegisterMessage(FileDef)

ModelVersion = _reflection.GeneratedProtocolMessageType('ModelVersion', (_message.Message,), dict(
  DESCRIPTOR = _MODELVERSION,
  __module__ = 'core.protos.model_pb2'
  # @@protoc_insertion_point(class_scope:modelhub.ModelVersion)
  ))
_sym_db.RegisterMessage(ModelVersion)

Model = _reflection.GeneratedProtocolMessageType('Model', (_message.Message,), dict(
  DESCRIPTOR = _MODEL,
  __module__ = 'core.protos.model_pb2'
  # @@protoc_insertion_point(class_scope:modelhub.Model)
  ))
_sym_db.RegisterMessage(Model)


_SAVEDMODELINFO_SIGNATUREDEFENTRY.has_options = True
_SAVEDMODELINFO_SIGNATUREDEFENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
# @@protoc_insertion_point(module_scope)
