# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorflow_serving/sources/storage_path/static_storage_path_source.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tensorflow_serving/sources/storage_path/static_storage_path_source.proto',
  package='tensorflow.serving',
  syntax='proto3',
  serialized_pb=_b('\nHtensorflow_serving/sources/storage_path/static_storage_path_source.proto\x12\x12tensorflow.serving\"a\n\x1dStaticStoragePathSourceConfig\x12\x15\n\rservable_name\x18\x01 \x01(\t\x12\x13\n\x0bversion_num\x18\x02 \x01(\x03\x12\x14\n\x0cversion_path\x18\x03 \x01(\tb\x06proto3')
)




_STATICSTORAGEPATHSOURCECONFIG = _descriptor.Descriptor(
  name='StaticStoragePathSourceConfig',
  full_name='tensorflow.serving.StaticStoragePathSourceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='servable_name', full_name='tensorflow.serving.StaticStoragePathSourceConfig.servable_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_num', full_name='tensorflow.serving.StaticStoragePathSourceConfig.version_num', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version_path', full_name='tensorflow.serving.StaticStoragePathSourceConfig.version_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=193,
)

DESCRIPTOR.message_types_by_name['StaticStoragePathSourceConfig'] = _STATICSTORAGEPATHSOURCECONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StaticStoragePathSourceConfig = _reflection.GeneratedProtocolMessageType('StaticStoragePathSourceConfig', (_message.Message,), dict(
  DESCRIPTOR = _STATICSTORAGEPATHSOURCECONFIG,
  __module__ = 'tensorflow_serving.sources.storage_path.static_storage_path_source_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.serving.StaticStoragePathSourceConfig)
  ))
_sym_db.RegisterMessage(StaticStoragePathSourceConfig)


# @@protoc_insertion_point(module_scope)
